==> basicdsp-1.0.tgz: basicdsp-1.0/book.h <==
/********************************************************************
  BasicDSP
  Copyright 2006-2007 
  Pieter-Tjerk de Boer PA3FWM pa3fwm@amsat.org
  Niels Moseley PE1OIT n.a.moseley@alumnus.utwente.nl
  License: GPLv2
********************************************************************/

#ifndef wxbook_h
#define wxbook_h

#include "wx/bookctrl.h"  // inlcude for wxBookCtrlBase

class wxBook : public wxBookCtrlBase
{
public:
  wxBook() {};

  wxBook(wxWindow *parent,
                 wxWindowID id,
                 const wxPoint& pos = wxDefaultPosition,
                 const wxSize& size = wxDefaultSize,
                 long style = 0);

  virtual ~wxBook();

  virtual int GetSelection() const { return m_selected;};
  virtual wxSize CalcSizeFromPage(const wxSize& sizePage) const;

  virtual int SetSelection(size_t n);

  // the same as AddPage(), but adds the page at the specified position
  virtual bool InsertPage(size_t n,
                          wxWindow *page,
                          const wxString& text,
                          bool bSelect = false,
                          int imageId = -1);



  // override functions of wxBookCtrlBase and make them do nothing:
  // set/get the title of a page
  virtual bool SetPageText(size_t n, const wxString& strText) {return false;};
  virtual wxString GetPageText(size_t n) const {return _T("");};
  virtual int GetPageImage(size_t n) const {return 0;};
  virtual bool SetPageImage(size_t n, int imageId) {return false;};

protected:
  //FIXME: make this work!
  virtual wxWindow *DoRemovePage(size_t page);

  wxRect GetPageRect() const;

  // event handlers
  void OnSize(wxSizeEvent& event);
  void OnSelected(wxCommandEvent& event);

  int m_selected;

private:
  DECLARE_EVENT_TABLE()
  DECLARE_DYNAMIC_CLASS_NO_COPY(wxBook)
};

#endif

==> basicdsp-1.01.tgz: basicdsp-1.01/book.h <==
/********************************************************************
  BasicDSP
  Copyright 2006-2007 
  Pieter-Tjerk de Boer PA3FWM pa3fwm@amsat.org
  Niels Moseley PE1OIT n.a.moseley@alumnus.utwente.nl
  License: GPLv2
********************************************************************/

#ifndef wxbook_h
#define wxbook_h

#include "wx/bookctrl.h"  // inlcude for wxBookCtrlBase

class wxBook : public wxBookCtrlBase
{
public:
  wxBook() {};

  wxBook(wxWindow *parent,
                 wxWindowID id,
                 const wxPoint& pos = wxDefaultPosition,
                 const wxSize& size = wxDefaultSize,
                 long style = 0);

  virtual ~wxBook();

  virtual int GetSelection() const { return m_selected;};
  virtual wxSize CalcSizeFromPage(const wxSize& sizePage) const;

  virtual int SetSelection(size_t n);     // should generate events
  virtual int ChangeSelection(size_t n);  // should not generate events

  // the same as AddPage(), but adds the page at the specified position
  virtual bool InsertPage(size_t n,
                          wxWindow *page,
                          const wxString& text,
                          bool bSelect = false,
                          int imageId = -1);



  // override functions of wxBookCtrlBase and make them do nothing:
  // set/get the title of a page
  virtual bool SetPageText(size_t n, const wxString& strText) {return false;};
  virtual wxString GetPageText(size_t n) const {return _T("");};
  virtual int GetPageImage(size_t n) const {return 0;};
  virtual bool SetPageImage(size_t n, int imageId) {return false;};

protected:
  //FIXME: make this work!
  virtual wxWindow *DoRemovePage(size_t page);

  wxRect GetPageRect() const;

  // event handlers
  void OnSize(wxSizeEvent& event);
  void OnSelected(wxCommandEvent& event);

  int m_selected;

private:
  DECLARE_EVENT_TABLE()
  DECLARE_DYNAMIC_CLASS_NO_COPY(wxBook)
};

#endif
